#[non_exhaustive]pub enum Error {
DeSerialization(DeSerError),
Poison,
Backend(BackendError),
WritePanic,
}Expand description
The different kinds of errors that can be returned
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DeSerialization(DeSerError)
A context error when a DeSerialization failed
Poison
This error is returned if the Database is poisoned. See
Database::write for details
Backend(BackendError)
An error in the backend happened
WritePanic
If Database::write_safe is used and the closure panics, this error is
returned